from __future__ import annotations

from pydantic import BaseModel


class DateObserved(BaseModel):
    type: str
    value: str


class Payload(BaseModel):
    victimid: str
    name: str
    surname: str
    dateofbirth: str
    age: int
    gender: str
    encounterdatetime: str
    triagestatus: str 
    totalgcs: int 
    dttid: str 
    currentdisposition: int
    incidentid: str
    contamination: bool
    longitude: float
    latitude: float
    chiefcomplaint: str
    chiefcomplaintname: str
    pregnant: bool
    gcseye: int
    gcsverbal: int
    gcsmotor: int
    nickname: str


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations

from pydantic import BaseModel

from datetime import datetime


class DateObserved(BaseModel):
    type: str
    value: datetime


class Payload(BaseModel):
    victimid: str
    incidentid: str
    devicetype: str
    respiratoryrate: float
    systolicbloodpressure: float
    diastolicbloodpressure: float
    temperature: float
    pulserate: float
    heartratevariability: float
    pulseoxymetry: float
    skinmoisture: float
    encounterdatetime: datetime


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations

from typing import Any, Dict, List, Optional

from pydantic import BaseModel
from datetime import datetime
from uuid_generator import UUIDGenerator


class VitalPredictions(BaseModel):
    HR: float
    RR: float
    SBP: float
    DBP: float
    SPO2: float


class VitalEarlyWarningScore(BaseModel):
    HR: int
    RR: int
    SBP: int
    DBP: int
    SPO2: int

class ProcedureMessage(BaseModel):
    procedureName: str
    predictedInterventionTimestamp: datetime
    message: str


class Prediction(BaseModel):
    timestamp: datetime
    earlyWarningScore: int
    vitalPredictions: VitalPredictions
    vitalEarlyWarningScore: VitalEarlyWarningScore
    shockIndex: float


class Model(BaseModel):
    UUID: str
    timestamp: datetime
    requestId: str
    lastMeasurementTimestamp: datetime
    predictionTimestampId: str
    predictionTimeDeltaMinutes: int
    victimId: str
    procedureMessageCount: int
    procedureMessages: List[ProcedureMessage]
    predictions: List[Prediction]